@@ -51,14 +51,11 @@ class PhantomInterface(
         )
         for x in ['mass', 'x', 'y', 'z', 'vx', 'vy', 'vz']:
             function.addParameter(x, dtype='float64', direction=function.IN)
-        function.addParameter(
-            'radius', dtype='float64', direction=function.IN, default=0.01,
-        )
         function.result_type = 'int32'
         return function
 
-    def new_particle(self, mass, x, y, z, vx, vy, vz, radius):
-        return self.new_dm_particle(mass, x, y, z, vx, vy, vz, radius)
+    def new_particle(self, mass, x, y, z, vx, vy, vz):
+        return self.new_dm_particle(mass, x, y, z, vx, vy, vz)
 
     @legacy_function
     def new_sph_particle():
@@ -129,9 +126,6 @@ class PhantomInterface(
         function.addParameter(
             'vz', dtype='float64', direction=function.OUT,
             description="The current velocity vector of the particle")
-        function.addParameter(
-            'radius', dtype='float64', direction=function.OUT,
-            description="The current softening length of the particle")
         function.result_type = 'int32'
         function.result_doc = """
         0 - OK
@@ -296,10 +290,10 @@ class PhantomInterface(
         return function
 
     def set_state(
-            self, index_of_the_particle, mass, x, y, z, vx, vy, vz, radius,
+            self, index_of_the_particle, mass, x, y, z, vx, vy, vz,
     ):
         return self.set_state_dm(
-            index_of_the_particle, mass, x, y, z, vx, vy, vz, radius)
+            index_of_the_particle, mass, x, y, z, vx, vy, vz)
 
     @legacy_function
     def set_state_dm():
@@ -335,9 +329,9 @@ class PhantomInterface(
         function.addParameter(
             'vz', dtype='float64', direction=function.IN,
             description="The new velocity vector of the particle")
-        function.addParameter(
-            'radius', dtype='float64', direction=function.IN,
-            description="The new softening length of the particle")
+        # function.addParameter(
+        #     'radius', dtype='float64', direction=function.IN,
+        #     description="The new softening length of the particle")
         function.result_type = 'int32'
         function.result_doc = """
         0 - OK
@@ -423,6 +417,101 @@ class PhantomInterface(
         """
         return function
 
+    @legacy_function
+    def set_h2ratio():
+        function = LegacyFunctionSpecification()
+        function.can_handle_array = True
+        function.addParameter(
+            'index_of_the_particle', dtype='int32', direction=function.IN,
+            description='',
+        )
+        function.addParameter(
+            'h2ratio', dtype='float64', direction=function.IN,
+            description='',
+        )
+        function.result_type = 'int32'
+        function.result_doc = """
+        0 - OK
+        -1 - ERROR
+        """
+        return function
+
+    @legacy_function
+    def set_hi_abundance():
+        function = LegacyFunctionSpecification()
+        function.can_handle_array = True
+        function.addParameter(
+            'index_of_the_particle', dtype='int32', direction=function.IN,
+            description='',
+        )
+        function.addParameter(
+            'hi_abundance', dtype='float64', direction=function.IN,
+            description='',
+        )
+        function.result_type = 'int32'
+        function.result_doc = """
+        0 - OK
+        -1 - ERROR
+        """
+        return function
+
+    @legacy_function
+    def set_proton_abundance():
+        function = LegacyFunctionSpecification()
+        function.can_handle_array = True
+        function.addParameter(
+            'index_of_the_particle', dtype='int32', direction=function.IN,
+            description='',
+        )
+        function.addParameter(
+            'proton_abundance', dtype='float64', direction=function.IN,
+            description='',
+        )
+        function.result_type = 'int32'
+        function.result_doc = """
+        0 - OK
+        -1 - ERROR
+        """
+        return function
+
+    @legacy_function
+    def set_electron_abundance():
+        function = LegacyFunctionSpecification()
+        function.can_handle_array = True
+        function.addParameter(
+            'index_of_the_particle', dtype='int32', direction=function.IN,
+            description='',
+        )
+        function.addParameter(
+            'electron_abundance', dtype='float64', direction=function.IN,
+            description='',
+        )
+        function.result_type = 'int32'
+        function.result_doc = """
+        0 - OK
+        -1 - ERROR
+        """
+        return function
+
+    @legacy_function
+    def set_co_abundance():
+        function = LegacyFunctionSpecification()
+        function.can_handle_array = True
+        function.addParameter(
+            'index_of_the_particle', dtype='int32', direction=function.IN,
+            description='',
+        )
+        function.addParameter(
+            'co_abundance', dtype='float64', direction=function.IN,
+            description='',
+        )
+        function.result_type = 'int32'
+        function.result_doc = """
+        0 - OK
+        -1 - ERROR
+        """
+        return function
+
     @legacy_function
     def set_smoothing_length():
         function = LegacyFunctionSpecification()
@@ -480,6 +569,101 @@ class PhantomInterface(
         """
         return function
 
+    @legacy_function
+    def get_h2ratio():
+        function = LegacyFunctionSpecification()
+        function.can_handle_array = True
+        function.addParameter(
+            'index_of_the_particle', dtype='int32', direction=function.IN,
+            description='',
+        )
+        function.addParameter(
+            'h2ratio', dtype='float64', direction=function.OUT,
+            description=''
+        )
+        function.result_type = 'int32'
+        function.result_doc = """
+        0 - OK
+        -1 - ERROR
+        """
+        return function
+
+    @legacy_function
+    def get_hi_abundance():
+        function = LegacyFunctionSpecification()
+        function.can_handle_array = True
+        function.addParameter(
+            'index_of_the_particle', dtype='int32', direction=function.IN,
+            description='',
+        )
+        function.addParameter(
+            'hi_abundance', dtype='float64', direction=function.OUT,
+            description=''
+        )
+        function.result_type = 'int32'
+        function.result_doc = """
+        0 - OK
+        -1 - ERROR
+        """
+        return function
+
+    @legacy_function
+    def get_proton_abundance():
+        function = LegacyFunctionSpecification()
+        function.can_handle_array = True
+        function.addParameter(
+            'index_of_the_particle', dtype='int32', direction=function.IN,
+            description='',
+        )
+        function.addParameter(
+            'proton_abundance', dtype='float64', direction=function.OUT,
+            description=''
+        )
+        function.result_type = 'int32'
+        function.result_doc = """
+        0 - OK
+        -1 - ERROR
+        """
+        return function
+
+    @legacy_function
+    def get_electron_abundance():
+        function = LegacyFunctionSpecification()
+        function.can_handle_array = True
+        function.addParameter(
+            'index_of_the_particle', dtype='int32', direction=function.IN,
+            description='',
+        )
+        function.addParameter(
+            'electron_abundance', dtype='float64', direction=function.OUT,
+            description=''
+        )
+        function.result_type = 'int32'
+        function.result_doc = """
+        0 - OK
+        -1 - ERROR
+        """
+        return function
+
+    @legacy_function
+    def get_co_abundance():
+        function = LegacyFunctionSpecification()
+        function.can_handle_array = True
+        function.addParameter(
+            'index_of_the_particle', dtype='int32', direction=function.IN,
+            description='',
+        )
+        function.addParameter(
+            'co_abundance', dtype='float64', direction=function.OUT,
+            description=''
+        )
+        function.result_type = 'int32'
+        function.result_doc = """
+        0 - OK
+        -1 - ERROR
+        """
+        return function
+
     @legacy_function
     def get_internal_energy():
         function = LegacyFunctionSpecification()
@@ -596,6 +780,31 @@ class PhantomInterface(
         """
         return function
 
+    @legacy_function
+    def get_c_cool():
+        function = LegacyFunctionSpecification()
+        function.addParameter(
+            'C_cool', dtype='float64', direction=function.OUT)
+        function.result_type = 'int32'
+        function.result_doc = """
+        0 - OK
+        -1 - ERROR
+        """
+        return function
+
+    @legacy_function
+    def set_c_cool():
+        function = LegacyFunctionSpecification()
+        function.addParameter(
+            'C_cool', dtype='float64', direction=function.IN)
+        function.result_type = 'int32'
+        function.result_doc = """
+        0 - OK
+        -1 - ERROR
+        """
+        return function
+
+
     @legacy_function
     def get_tolv():
         function = LegacyFunctionSpecification()
@@ -1232,7 +1441,21 @@ class PhantomInterface(
     def get_unit_length():
         function = LegacyFunctionSpecification()
         function.addParameter(
-            'code_unit_length', dtype='float64', direction=function.OUT,
+            'unit_length', dtype='float64', direction=function.OUT,
+            unit=units.cm  # generic_unit_system.length
+        )
+        function.result_type = 'int32'
+        function.result_doc = """
+        0 - OK
+        -1 - ERROR
+        """
+        return function
+
+    @legacy_function
+    def set_unit_length():
+        function = LegacyFunctionSpecification()
+        function.addParameter(
+            'unit_length', dtype='float64', direction=function.IN,
             unit=units.cm  # generic_unit_system.length
         )
         function.result_type = 'int32'
@@ -1246,7 +1469,21 @@ class PhantomInterface(
     def get_unit_mass():
         function = LegacyFunctionSpecification()
         function.addParameter(
-            'code_unit_mass', dtype='float64', direction=function.OUT,
+            'unit_mass', dtype='float64', direction=function.OUT,
+            unit=units.g  # generic_unit_system.mass
+        )
+        function.result_type = 'int32'
+        function.result_doc = """
+        0 - OK
+        -1 - ERROR
+        """
+        return function
+
+    @legacy_function
+    def set_unit_mass():
+        function = LegacyFunctionSpecification()
+        function.addParameter(
+            'unit_mass', dtype='float64', direction=function.IN,
             unit=units.g  # generic_unit_system.mass
         )
         function.result_type = 'int32'
@@ -1260,7 +1497,7 @@ class PhantomInterface(
     def get_unit_time():
         function = LegacyFunctionSpecification()
         function.addParameter(
-            'code_unit_time', dtype='float64', direction=function.OUT,
+            'unit_time', dtype='float64', direction=function.OUT,
             unit=units.s  # generic_unit_system.time
         )
         function.result_type = 'int32'
@@ -1271,11 +1508,11 @@ class PhantomInterface(
         return function
 
     @legacy_function
-    def get_constant_solarm():
+    def set_unit_time():
         function = LegacyFunctionSpecification()
         function.addParameter(
-            'physcon_solarm', dtype='float64', direction=function.OUT,
-            unit=units.g
+            'unit_time', dtype='float64', direction=function.IN,
+            unit=units.s  # generic_unit_system.time
         )
         function.result_type = 'int32'
         function.result_doc = """
@@ -1284,37 +1521,6 @@ class PhantomInterface(
         """
         return function
 
-    @legacy_function
-    def get_constant_pc():
-        function = LegacyFunctionSpecification()
-        function.addParameter(
-            'physcon_pc', dtype='float64', direction=function.OUT,
-            unit=units.cm
-        )
-        function.result_type = 'int32'
-        function.result_doc = """
-        0 - OK
-        -1 - ERROR
-        """
-        return function
-
-    @legacy_function
-    def get_constant_planckh():
-        function = LegacyFunctionSpecification()
-        function.addParameter(
-            'physcon_planckh', dtype='float64', direction=function.OUT,
-            unit=units.erg * units.s
-        )
-        function.result_type = 'int32'
-        function.result_doc = """
-        0 - OK
-        -1 - ERROR
-        """
-        return function
-
-    def reinitialize_particles(self):
-        self.recommit_particles()
-
 
 class Phantom(GravitationalDynamics, GravityFieldCode):
     __interface__ = PhantomInterface
@@ -1323,20 +1529,30 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
             self,
             convert_nbody=None,
             **options):
-        if convert_nbody is None:
-            phantom_solarm = 1.9891e33 | units.g
-            phantom_pc = 3.086e18 | units.cm
-            phantom_gg = 6.672041e-8 | units.cm**3 * units.g**-1 * units.s**-2
-            phantom_length = 0.1 * phantom_pc
-            phantom_mass = 1.0 * phantom_solarm
-            unit_converter = ConvertBetweenGenericAndSiUnits(
-                # Phantom uses CGS units internally, scaled with G=1
-                # So we need to make sure we use those same units here...
-                phantom_length,  # 0.1 pc
-                phantom_mass,  # 1.0 MSun
-                (phantom_length**3 / (phantom_gg*phantom_mass))**0.5,
-            )
-            convert_nbody = unit_converter
+        # if convert_nbody is None:
+        # NOTE we use a fixed converter here internally!
+        # Not doing this *really* complicates things as we'd need to change the
+        # internal units used in Phantom as well.
+        phantom_solarm = 1.9891e33 | units.g
+        phantom_pc = 3.086e18 | units.cm
+        phantom_gg = 6.672041e-8 | units.cm**3 * units.g**-1 * units.s**-2
+        # phantom_mass = 1.0 | units.MSun
+        # phantom_mass = 1.98892e33 | units.g
+        # phantom_time = 60 * 60 * 24 * 365.25 * 1e6 | units.s
+        # phantom_length = (phantom_time**2 * phantom_gg * phantom_mass)**(1/3)
+        phantom_mass = 1.0 * phantom_solarm
+        phantom_length = 0.1 * phantom_pc
+        phantom_time = (phantom_length**3 / (phantom_gg*phantom_mass))**0.5
+
+        unit_converter = ConvertBetweenGenericAndSiUnits(
+            # Phantom uses CGS units internally, scaled with G=1
+            # So we need to make sure we use those same units here...
+            # Also, Phantom's value for G is not the same as AMUSE's...
+            phantom_length,
+            phantom_mass,  # 1.0 MSun
+            phantom_time,  # 1 Julian Myr
+        )
+        convert_nbody = unit_converter
 
         self.stopping_conditions = StoppingConditions(self)
 
@@ -1349,6 +1565,12 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
 
     def initialize_code(self):
         result = self.overridden().initialize_code()
+
+        if self.unit_converter is not None:
+            mass = self.unit_converter.to_si(generic_unit_system.mass)
+            time = self.unit_converter.to_si(generic_unit_system.time)
+            # self.parameters._original.unit_mass = mass
+            # self.parameters._original.unit_time = time
         # self.set_unit_mass(self.unit_converter.to_si(generic_unit_system.mass).value_in(units.g))
         # self.set_unit_length(self.unit_converter.to_si(generic_unit_system.length).value_in(units.cm))
         # self.set_unit_time(self.unit_converter.to_si(generic_unit_system.time).value_in(units.s))
@@ -1386,7 +1608,7 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
         handler.add_method_parameter(
             "get_c_courant",
             "set_c_courant",
-            "C_cour",
+            "c_courant",
             "Courant number",
             default_value=0.3
         )
@@ -1394,11 +1616,19 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
         handler.add_method_parameter(
             "get_c_force",
             "set_c_force",
-            "C_force",
+            "c_force",
             "dt_force number",
             default_value=0.25
         )
 
+        handler.add_method_parameter(
+            "get_c_cool",
+            "set_c_cool",
+            "c_cool",
+            "dt_cool number",
+            default_value=0.25
+        )
+
         handler.add_method_parameter(
             "get_tolv",
             "set_tolv",
@@ -1476,7 +1706,7 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
             "set_polyk",
             "polyk",
             "polyk value",
-            default_value=(0.0349200860019 | units.km**2 * units.s**-2)
+            default_value=(0. | units.km**2 * units.s**-2)
         )
 
         handler.add_method_parameter(
@@ -1524,7 +1754,7 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
             "set_rho_crit",
             "rho_crit",
             "density above which sink particles are created",
-            default_value=(1e-16 | units.g * units.cm**-3)
+            default_value=(1e-10 | units.g * units.cm**-3)
         )
 
         handler.add_method_parameter(
@@ -1533,7 +1763,7 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
             "r_crit",
             "critical radius for point mass creation"
             " (no new sinks < r_crit from existing sink)",
-            default_value=(0.001 | generic_unit_system.length)
+            default_value=(0.005 | generic_unit_system.length)
         )
 
         handler.add_method_parameter(
@@ -1549,7 +1779,7 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
             "set_h_soft_sinkgas",
             "h_soft_sinkgas",
             "softening length for new sink particles",
-            default_value=(0.001 | generic_unit_system.length)
+            default_value=(0. | generic_unit_system.length)
         )
 
         handler.add_method_parameter(
@@ -1557,7 +1787,7 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
             "set_h_soft_sinksink",
             "h_soft_sinksink",
             "softening length between sink particles",
-            default_value=(0.001 | generic_unit_system.length)
+            default_value=(0. | generic_unit_system.length)
         )
 
         handler.add_method_parameter(
@@ -1604,56 +1834,30 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
 
         handler.add_method_parameter(
             "get_unit_length",
-            None,
+            "set_unit_length",
             "code_unit_length",
             "code unit length",
-            default_value=0.1 * 3.086e18 | units.cm
+            default_value=(
+                ((60 * 60 * 24 * 365.25 * 1e6) | units.s)**2
+                * (6.672041e-8 | units.cm**3 * units.g**-1 * units.s**-2)
+                * (1.98892e33 | units.g)
+            )**(1/3)
         )
 
         handler.add_method_parameter(
             "get_unit_mass",
-            None,
+            "set_unit_mass",
             "code_unit_mass",
             "code unit mass",
-            default_value=1.9891e33 | units.g
+            default_value=1.98892e33 | units.g
         )
 
         handler.add_method_parameter(
             "get_unit_time",
-            None,
+            "set_unit_time",
             "code_unit_time",
             "code unit time",
-            default_value=(
-                (0.1 * 3.086e18 | units.cm)**3
-                / (
-                    (6.672041e-8 | units.cm**3 * units.g**-1 * units.s**-2)
-                    * (1.9891e33 | units.g)
-                )
-            )**0.5
-        )
-
-        handler.add_method_parameter(
-            "get_constant_pc",
-            None,
-            "physcon_pc",
-            "parsec (cm)",
-            default_value=3.086e18 | units.cm
-        )
-
-        handler.add_method_parameter(
-            "get_constant_solarm",
-            None,
-            "physcon_solarm",
-            "solar mass (g)",
-            default_value=1.9891e33 | units.g
-        )
-
-        handler.add_method_parameter(
-            "get_constant_planckh",
-            None,
-            "physcon_planckh",
-            "Planck constant (cm)",
-            default_value=6.6260755e-27 | units.erg * units.s
+            default_value=3.15576e13 | units.s
         )
 
         self.stopping_conditions.define_parameters(handler)
@@ -1676,8 +1880,7 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
         handler.add_setter('dm_particles', 'set_position')
         handler.add_getter('dm_particles', 'get_velocity')
         handler.add_setter('dm_particles', 'set_velocity')
-        handler.add_getter('dm_particles', 'get_radius')
-        handler.add_setter('dm_particles', 'set_radius')
+        handler.add_getter('dm_particles', 'get_acceleration')
 
         handler.define_set('gas_particles', 'index_of_the_particle')
         handler.set_new('gas_particles', 'new_sph_particle')
@@ -1690,6 +1893,7 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
         handler.add_setter('gas_particles', 'set_position')
         handler.add_getter('gas_particles', 'get_velocity')
         handler.add_setter('gas_particles', 'set_velocity')
+        handler.add_getter('gas_particles', 'get_acceleration')
         handler.add_getter('gas_particles', 'get_internal_energy')
         handler.add_setter('gas_particles', 'set_internal_energy')
         handler.add_getter('gas_particles', 'get_smoothing_length')
@@ -1697,6 +1901,16 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
         handler.add_getter('gas_particles', 'get_density', names=('rho',))
         handler.add_getter('gas_particles', 'get_density', names=('density',))
         handler.add_getter('gas_particles', 'get_pressure')
+        handler.add_getter('gas_particles', 'get_h2ratio')
+        handler.add_getter('gas_particles', 'get_hi_abundance')
+        handler.add_getter('gas_particles', 'get_proton_abundance')
+        handler.add_getter('gas_particles', 'get_electron_abundance')
+        handler.add_getter('gas_particles', 'get_co_abundance')
+        handler.add_setter('gas_particles', 'set_h2ratio')
+        handler.add_setter('gas_particles', 'set_hi_abundance')
+        handler.add_setter('gas_particles', 'set_proton_abundance')
+        handler.add_setter('gas_particles', 'set_electron_abundance')
+        handler.add_setter('gas_particles', 'set_co_abundance')
 
         handler.define_set('sink_particles', 'index_of_the_particle')
         handler.set_new('sink_particles', 'new_sink_particle')
@@ -1709,6 +1923,7 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
         handler.add_setter('sink_particles', 'set_position')
         handler.add_getter('sink_particles', 'get_velocity')
         handler.add_setter('sink_particles', 'set_velocity')
+        handler.add_getter('sink_particles', 'get_acceleration')
         handler.add_getter('sink_particles', 'get_radius')
         handler.add_setter('sink_particles', 'set_radius')
         handler.add_getter('sink_particles', 'get_smoothing_length')
@@ -1729,7 +1944,6 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
                 generic_unit_system.speed,
                 generic_unit_system.speed,
                 generic_unit_system.speed,
-                generic_unit_system.length,
             ),
             (
                 handler.INDEX,
@@ -1788,7 +2002,6 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
                 generic_unit_system.speed,
                 generic_unit_system.speed,
                 generic_unit_system.speed,
-                generic_unit_system.length,
                 handler.ERROR_CODE,
             )
         )
@@ -1804,7 +2017,7 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
                 generic_unit_system.speed,
                 generic_unit_system.speed,
                 generic_unit_system.speed,
-                generic_unit_system.length,
+                # generic_unit_system.length,
             ),
             (
                 handler.ERROR_CODE,
@@ -1931,6 +2144,61 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
             )
         )
 
+        handler.add_method(
+            "get_h2ratio",
+            (
+                handler.INDEX,
+            ),
+            (
+                handler.NO_UNIT,
+                handler.ERROR_CODE,
+            )
+        )
+
+        handler.add_method(
+            "get_hi_abundance",
+            (
+                handler.INDEX,
+            ),
+            (
+                handler.NO_UNIT,
+                handler.ERROR_CODE,
+            )
+        )
+
+        handler.add_method(
+            "get_proton_abundance",
+            (
+                handler.INDEX,
+            ),
+            (
+                handler.NO_UNIT,
+                handler.ERROR_CODE,
+            )
+        )
+
+        handler.add_method(
+            "get_electron_abundance",
+            (
+                handler.INDEX,
+            ),
+            (
+                handler.NO_UNIT,
+                handler.ERROR_CODE,
+            )
+        )
+
+        handler.add_method(
+            "get_co_abundance",
+            (
+                handler.INDEX,
+            ),
+            (
+                handler.NO_UNIT,
+                handler.ERROR_CODE,
+            )
+        )
+
         handler.add_method(
             "get_internal_energy",
             (
@@ -1953,4 +2221,79 @@ class Phantom(GravitationalDynamics, GravityFieldCode):
             )
         )
 
+        handler.add_method(
+            "set_h2ratio",
+            (
+                handler.INDEX,
+                handler.NO_UNIT,
+            ),
+            (
+                handler.ERROR_CODE,
+            )
+        )
+
+        handler.add_method(
+            "set_hi_abundance",
+            (
+                handler.INDEX,
+                handler.NO_UNIT,
+            ),
+            (
+                handler.ERROR_CODE,
+            )
+        )
+
+        handler.add_method(
+            "set_proton_abundance",
+            (
+                handler.INDEX,
+                handler.NO_UNIT,
+            ),
+            (
+                handler.ERROR_CODE,
+            )
+        )
+
+        handler.add_method(
+            "set_electron_abundance",
+            (
+                handler.INDEX,
+                handler.NO_UNIT,
+            ),
+            (
+                handler.ERROR_CODE,
+            )
+        )
+
+        handler.add_method(
+            "set_co_abundance",
+            (
+                handler.INDEX,
+                handler.NO_UNIT,
+            ),
+            (
+                handler.ERROR_CODE,
+            )
+        )
+
+        handler.add_method(
+            "get_time_step",
+            (
+            ),
+            (
+                generic_unit_system.time,
+                handler.ERROR_CODE,
+            )
+        )
+
+        handler.add_method(
+            "set_time_step",
+            (
+                generic_unit_system.time,
+            ),
+            (
+                handler.ERROR_CODE,
+            )
+        )
+
         self.stopping_conditions.define_methods(handler)
